==> react-atom-slider-1.24.0.tgz: package/lib/Handler.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["value", "index", "dragging", "refAtomSlider", "hideTooltip", "className"];
import { useRef, useState, useEffect } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { Handle, Tooltip, BASE_CLASS } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";

var Handler = function Handler(_ref) {
  var value = _ref.value,
      index = _ref.index,
      dragging = _ref.dragging,
      refAtomSlider = _ref.refAtomSlider,
      hideTooltip = _ref.hideTooltip,
      handleClassName = _ref.className,
      restProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var refHandle = useRef();

  var _useState = useState(false),
      ready = _useState[0],
      setReady = _useState[1];

  useEffect(function () {
    if (!ready) setReady(!ready);
  }, [ready]);

  if (!(refAtomSlider != null && refAtomSlider.current)) {
    return null;
  }

  if (hideTooltip) {
    return /*#__PURE__*/_jsx(Handle, _extends({
      value: value
    }, restProps));
  }

  return /*#__PURE__*/_jsx(Tooltip, {
    getTooltipContainer: function getTooltipContainer() {
      var _refHandle$current;

      return refHandle == null ? void 0 : (_refHandle$current = refHandle.current) == null ? void 0 : _refHandle$current.handle;
    },
    prefixCls: "rc-slider-tooltip",
    overlay: value,
    placement: "top",
    visible: true,
    children: /*#__PURE__*/_jsx(Handle, _extends({
      ref: refHandle,
      value: value
    }, restProps, {
      className: cx(BASE_CLASS + "-handle", handleClassName)
    }))
  }, index);
};

export default Handler;

==> react-atom-slider-1.25.0.tgz: package/lib/Handler.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["value", "index", "dragging", "refAtomSlider", "hideTooltip", "className"];
import { useRef } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { Handle, Tooltip, BASE_CLASS } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";

var Handler = function Handler(_ref) {
  var value = _ref.value,
      index = _ref.index,
      dragging = _ref.dragging,
      refAtomSlider = _ref.refAtomSlider,
      hideTooltip = _ref.hideTooltip,
      handleClassName = _ref.className,
      restProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var refHandle = useRef();

  if (!(refAtomSlider != null && refAtomSlider.current)) {
    return null;
  }

  if (hideTooltip) {
    return /*#__PURE__*/_jsx(Handle, _extends({
      value: value
    }, restProps));
  }

  return process.browser && /*#__PURE__*/_jsx(Tooltip, {
    getTooltipContainer: function getTooltipContainer() {
      var _refHandle$current;

      return refHandle == null ? void 0 : (_refHandle$current = refHandle.current) == null ? void 0 : _refHandle$current.handle;
    },
    prefixCls: "rc-slider-tooltip",
    overlay: value,
    placement: "top",
    visible: true,
    children: /*#__PURE__*/_jsx(Handle, _extends({
      ref: refHandle,
      value: value
    }, restProps, {
      className: cx(BASE_CLASS + "-handle", handleClassName)
    }))
  }, index);
};

export default Handler;
